@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2016 Luis Falcon <lfalcon@gnu.org>
+#    Copyright (C) 2008-2017 Luis Falcon <lfalcon@gnu.org>
 #    Copyright (C) 2013  Sebastián Marro <smarro@thymbra.com>
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -69,6 +69,11 @@ class ImagingTest(ModelSQL, ModelView):
         required=True)
     product = fields.Many2One('product.product', 'Service', required=True)
 
+    active = fields.Boolean('Active', select=True)
+
+    @staticmethod
+    def default_active():
+        return True
 
 class ImagingTestRequest(Workflow, ModelSQL, ModelView):
     'Imaging Test Request'
