@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2016 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2016 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2017 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2017 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -21,5 +21,5 @@
 #
 ##############################################################################
 
-from wizard_create_prescription_stock_move import *
-from wizard_create_vaccination_stock_move import *
+from .wizard_create_prescription_stock_move import *
+from .wizard_create_vaccination_stock_move import *
